@@ -15,8 +15,8 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-// $Name: IMKIT_0_4_0 $
-// $Id: uim_keyevent.cpp,v 1.13 2004/03/06 15:27:01 yamaken Exp $
+// $Name: IMKIT_0_4_1 $
+// $Id: uim_keyevent.cpp,v 1.14 2004/04/12 02:14:57 yamaken Exp $
 
 #include <ctype.h>
 #include "keyfilter.h"
@@ -212,10 +212,20 @@ UIMKeyEvent::UIMKeyEvent(const QKeyEvent &e)
   qt_keycode = (Qt::Key)e.key();
   chr = KeyEventConverter::extract_qchar(e);
 
+#ifdef IMKIT_BROKEN_SL6000_QTKEYCODE
+  // SL-6000 has following broken Qt keycode map, so ordinary logic is
+  // not working correctly.
+  // Ctrl-g : Qt::Key_yen
+  // Ctrl-h : Qt::Key_cent
+  // Ctrl-j : Qt::Key_sterling
+  keycode = q2u_keycode.ordinary_map.lookup(qt_keycode);
+  if (keycode == (UKey)0
+#else
   if (iscntrl(e.ascii()) && !isascii(qt_keycode)) {
     keycode = q2u_keycode.ordinary_map.lookup(qt_keycode);
   } else if (isascii(qt_keycode)
              && qt_keycode
+#endif
              && (isgraph(chr.latin1())
                  || isspace(chr.latin1())
                  || iscntrl(chr.latin1())))
