@@ -15,8 +15,8 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-// $Name: IMKIT_0_4_0 $
-// $Id: keyfilter.cpp,v 1.11 2004/03/07 07:07:43 yamaken Exp $
+// $Name: IMKIT_0_4_1 $
+// $Id: keyfilter.cpp,v 1.12 2004/04/12 02:14:58 yamaken Exp $
 
 #include <ctype.h>
 #include "keyfilter.h"
@@ -36,8 +36,12 @@ imkit_delete_command_map(CommandMap *command_map) {
 
 unsigned char
 imkit_strip_control(unsigned char chr) {
-  if (iscntrl(chr) && chr != 0x7f) {
-    chr += '`';
+  if (iscntrl(chr)) {
+    if (chr == 0) {
+      chr = ' ';
+    } else if (chr != 0x7f) {
+      chr += '`';
+    }
   }
 
   return chr;
